@@ -23,6 +23,7 @@ from .utils import (
     datetime_to_epoch,
     format_lazy,
     get_md5_hash_password,
+    logger,
 )
 
 if TYPE_CHECKING:
@@ -62,10 +63,10 @@ class Token:
             # Decode token
             try:
                 self.payload = token_backend.decode(token, verify=verify)
-            except TokenBackendExpiredToken:
-                raise ExpiredTokenError(_("Token is expired"))
-            except TokenBackendError:
-                raise TokenError(_("Token is invalid"))
+            except TokenBackendExpiredToken as e:
+                raise ExpiredTokenError(_("Token is expired")) from e
+            except TokenBackendError as e:
+                raise TokenError(_("Token is invalid")) from e
 
             if verify:
                 self.verify()
@@ -134,8 +135,8 @@ class Token:
         """
         try:
             token_type = self.payload[api_settings.TOKEN_TYPE_CLAIM]
-        except KeyError:
-            raise TokenError(_("Token has no type"))
+        except KeyError as e:
+            raise TokenError(_("Token has no type")) from e
 
         if self.token_type != token_type:
             raise TokenError(_("Token has wrong type"))
@@ -196,38 +197,20 @@ class Token:
 
         try:
             claim_value = self.payload[claim]
-        except KeyError:
-            raise TokenError(format_lazy(_("Token has no '{}' claim"), claim))
+        except KeyError as e:
+            raise TokenError(format_lazy(_("Token has no '{}' claim"), claim)) from e
 
         claim_time = datetime_from_epoch(claim_value)
         leeway = self.get_token_backend().get_leeway()
         if claim_time <= current_time - leeway:
             raise TokenError(format_lazy(_("Token '{}' claim has expired"), claim))
 
-    def outstand(self) -> OutstandingToken:
+    def outstand(self) -> Optional[OutstandingToken]:
         """
         Ensures this token is included in the outstanding token list and
         adds it to the outstanding token list if not.
         """
-        jti = self.payload[api_settings.JTI_CLAIM]
-        exp = self.payload["exp"]
-        user_id = self.payload.get(api_settings.USER_ID_CLAIM)
-        User = get_user_model()
-        try:
-            user = User.objects.get(**{api_settings.USER_ID_FIELD: user_id})
-        except User.DoesNotExist:
-            user = None
-
-        # Ensure outstanding token exists with given jti
-        return OutstandingToken.objects.get_or_create(
-            jti=jti,
-            defaults={
-                "user": user,
-                "created_at": self.current_time,
-                "token": str(self),
-                "expires_at": datetime_from_epoch(exp),
-            },
-        )
+        return None
 
     @classmethod
     def for_user(cls: type[T], user: AuthUser) -> T:
@@ -235,9 +218,14 @@ class Token:
         Returns an authorization token for the given user that will be provided
         after authenticating the user's credentials.
         """
+
+        if hasattr(user, "is_active") and not user.is_active:
+            logger.warning(
+                f"Creating token for inactive user: {user.id}. If this is not intentional, consider checking the user's status before calling the `for_user` method."
+            )
+
         user_id = getattr(user, api_settings.USER_ID_FIELD)
-        if not isinstance(user_id, int):
-            user_id = str(user_id)
+        user_id = str(user_id)
 
         token = cls()
         token[api_settings.USER_ID_CLAIM] = user_id
@@ -318,6 +306,31 @@ class BlacklistMixin(Generic[T]):
 
             return BlacklistedToken.objects.get_or_create(token=token)
 
+        def outstand(self) -> Optional[OutstandingToken]:
+            """
+            Ensures this token is included in the outstanding token list and
+            adds it to the outstanding token list if not.
+            """
+            jti = self.payload[api_settings.JTI_CLAIM]
+            exp = self.payload["exp"]
+            user_id = self.payload.get(api_settings.USER_ID_CLAIM)
+            User = get_user_model()
+            try:
+                user = User.objects.get(**{api_settings.USER_ID_FIELD: user_id})
+            except User.DoesNotExist:
+                user = None
+
+            # Ensure outstanding token exists with given jti
+            return OutstandingToken.objects.get_or_create(
+                jti=jti,
+                defaults={
+                    "user": user,
+                    "created_at": self.current_time,
+                    "token": str(self),
+                    "expires_at": datetime_from_epoch(exp),
+                },
+            )
+
         @classmethod
         def for_user(cls: type[T], user: AuthUser) -> T:
             """
@@ -372,6 +385,7 @@ class RefreshToken(BlacklistMixin["RefreshToken"], Token):
         # we wouldn't want to copy either one.
         api_settings.JTI_CLAIM,
         "jti",
+        "iat",
     )
     access_token_class = AccessToken
 
